@@ -34,7 +34,7 @@ class Invites(Namespace):
     base_url = "https://api.xata.io"
     scope = "core"
 
-    def inviteWorkspaceMember(self, workspace_id: str, payload: dict) -> Response:
+    def inviteWorkspaceMember(self, payload: dict, workspace_id: str = None) -> Response:
         """
         Invite some user to join the workspace with the given role
 
@@ -50,18 +50,18 @@ class Invites(Namespace):
         - 5XX: Unexpected Error
         Response: application/json
 
-        :param workspace_id: str Workspace ID
         :param payload: dict content
+        :param workspace_id: str = None The workspace identifier. Default: workspace Id from the client.
 
         :return Response
         """
+        if workspace_id is None:
+            workspace_id = self.client.get_config()["workspaceId"]
         url_path = f"/workspaces/{workspace_id}/invites"
         headers = {"content-type": "application/json"}
         return self.request("POST", url_path, headers, payload)
 
-    def cancelWorkspaceMemberInvite(
-        self, workspace_id: str, invite_id: str
-    ) -> Response:
+    def cancelWorkspaceMemberInvite(self, invite_id: str, workspace_id: str = None) -> Response:
         """
         This operation provides a way to cancel invites by deleting them.  Already accepted
         invites cannot be deleted.
@@ -76,17 +76,17 @@ class Invites(Namespace):
         - 404: Example response
         - 5XX: Unexpected Error
 
-        :param workspace_id: str Workspace ID
         :param invite_id: str Invite identifier
+        :param workspace_id: str = None The workspace identifier. Default: workspace Id from the client.
 
         :return Response
         """
+        if workspace_id is None:
+            workspace_id = self.client.get_config()["workspaceId"]
         url_path = f"/workspaces/{workspace_id}/invites/{invite_id}"
         return self.request("DELETE", url_path)
 
-    def updateWorkspaceMemberInvite(
-        self, workspace_id: str, invite_id: str, payload: dict
-    ) -> Response:
+    def updateWorkspaceMemberInvite(self, invite_id: str, payload: dict, workspace_id: str = None) -> Response:
         """
         This operation provides a way to update an existing invite.  Updates are performed in-
         place; they do not change the invite link, the expiry time, nor do they re-notify the
@@ -104,19 +104,19 @@ class Invites(Namespace):
         - 5XX: Unexpected Error
         Response: application/json
 
-        :param workspace_id: str Workspace ID
         :param invite_id: str Invite identifier
         :param payload: dict content
+        :param workspace_id: str = None The workspace identifier. Default: workspace Id from the client.
 
         :return Response
         """
+        if workspace_id is None:
+            workspace_id = self.client.get_config()["workspaceId"]
         url_path = f"/workspaces/{workspace_id}/invites/{invite_id}"
         headers = {"content-type": "application/json"}
         return self.request("PATCH", url_path, headers, payload)
 
-    def acceptWorkspaceMemberInvite(
-        self, workspace_id: str, invite_key: str
-    ) -> Response:
+    def acceptWorkspaceMemberInvite(self, invite_key: str, workspace_id: str = None) -> Response:
         """
         Accept the invitation to join a workspace.  If the operation succeeds the user will be a
         member of the workspace
@@ -131,17 +131,17 @@ class Invites(Namespace):
         - 404: Example response
         - 5XX: Unexpected Error
 
-        :param workspace_id: str Workspace ID
         :param invite_key: str Invite Key (secret) for the invited user
+        :param workspace_id: str = None The workspace identifier. Default: workspace Id from the client.
 
         :return Response
         """
+        if workspace_id is None:
+            workspace_id = self.client.get_config()["workspaceId"]
         url_path = f"/workspaces/{workspace_id}/invites/{invite_key}/accept"
         return self.request("POST", url_path)
 
-    def resendWorkspaceMemberInvite(
-        self, workspace_id: str, invite_id: str
-    ) -> Response:
+    def resendWorkspaceMemberInvite(self, invite_id: str, workspace_id: str = None) -> Response:
         """
         This operation provides a way to resend an Invite notification.  Invite notifications can
         only be sent for Invites not yet accepted.
@@ -156,10 +156,12 @@ class Invites(Namespace):
         - 404: Example response
         - 5XX: Unexpected Error
 
-        :param workspace_id: str Workspace ID
         :param invite_id: str Invite identifier
+        :param workspace_id: str = None The workspace identifier. Default: workspace Id from the client.
 
         :return Response
         """
+        if workspace_id is None:
+            workspace_id = self.client.get_config()["workspaceId"]
         url_path = f"/workspaces/{workspace_id}/invites/{invite_id}/resend"
         return self.request("POST", url_path)
